@@ -19,3 +19,12 @@ __PACKAGE__->meta->make_immutable;
 
 
 1;
+
+__END__;
+
+
+=head1 NAME
+
+Reaction::InterfaceModel::ObjectClass
+
+=cut
