@@ -4,7 +4,6 @@ use Reaction::UI::WidgetClass;
 
 use namespace::clean -except => [ qw(meta) ];
 
-
 implements fragment members {
   render member => over $_{viewport}->members;
 };
@@ -13,6 +12,14 @@ implements fragment member {
   render 'viewport';
 };
 
+implements fragment actions {
+  render action => over $_{viewport}->actions;
+};
+
+implements fragment action {
+  render 'viewport';
+};
+
 __PACKAGE__->meta->make_immutable;
 
 
